Crate libstrophe_sys_bindgen [−] [src]
libstrophe C library bindings
This crate provides bindings to libstrophe C library which enables you the creation of XMPP
clients and servers. The bindings were statically generated using bindgen so the crate doesn't
have a hard dependency on bindgen. If you still want to regenerate the bindings during building
of the create, enable buildtime_bindgen feature.
Usage of this crate creates runtime dependency on libstrophe.so so be sure to install that using your package manager.
Current bindings were generated from libstrophe version: 0.9.1
The difference from libstrophe-sys crate is the this one is automatically generated hence easier to maintain.
This crate contains only C bindings, for Rust ergonomic interface see libstrophe crate.
Structs
| _xmpp_conn_t | |
| _xmpp_ctx_t | |
| _xmpp_log_t | |
| _xmpp_mem_t | |
| _xmpp_sha1_t | |
| _xmpp_stanza_t | |
| xmpp_stream_error_t |
Enums
| xmpp_conn_event_t | |
| xmpp_conn_type_t | |
| xmpp_error_type_t | |
| xmpp_log_level_t |
Constants
Functions
Type Definitions
| xmpp_conn_handler | |
| xmpp_conn_t | |
| xmpp_ctx_t | |
| xmpp_handler | |
| xmpp_log_handler | |
| xmpp_log_t | |
| xmpp_mem_t | |
| xmpp_sha1_t | |
| xmpp_stanza_t | |
| xmpp_timed_handler |